@@ -1,5 +1,5 @@
 package Log::Dispatch::FileRotate;
-$Log::Dispatch::FileRotate::VERSION = '1.22';
+$Log::Dispatch::FileRotate::VERSION = '1.23';
 # ABSTRACT: Log to Files that Archive/Rotate Themselves
 
 require 5.005;
@@ -207,7 +207,7 @@ sub log_message
 		warn "$$ waiting on lock\n" if $self->{debug};
 		unless($self->lfhlock())
 		{
-			warn "$$ failed to get lock. returning\n" if $self->{debug};
+			warn "$$ Log::Dispatch::FileRotate failed to get lock: ", $self->{_lfhlock_test_err}, ". Not logging.\n";
 			return;
 		}
 		warn "$$ got lock after wait\n" if $self->{debug};
@@ -293,7 +293,7 @@ sub DESTROY
 
 	# Clean up locks
 	close $self->{lfh} if $self->{lfh};
- 	unlink $self->{lf} if -f $self->{lf};
+ 	unlink $self->{lf} if $self->{lf} && -f $self->{lf};
 }
 
 sub logit
@@ -627,6 +627,7 @@ sub lfhlock_test
 	}
 	else
 	{
+		$self->{_lfhlock_test_err} = "couldn't lock $self->{lf}: $!";
 		$self->{lfh} = 0;
 		warn "$$ couldn't get lock on Lock File\n" if $self->{debug};
 		return 0;
@@ -676,7 +677,7 @@ Log::Dispatch::FileRotate - Log to Files that Archive/Rotate Themselves
 
 =head1 VERSION
 
-version 1.22
+version 1.23
 
 =head1 SYNOPSIS
 
@@ -743,7 +744,7 @@ Log::Dispatch::FileRotate->new() to be called by each of the writers
 close to the same time, and if your recurrences aren't too close together
 all should sync up just nicely.
 
-I initially aasumed a long runinng process but it seems people are using
+I initially assumed a long running process but it seems people are using
 this module as part of short running CGI programs. So, now we look at the
 last modified time stamp of the log file and compare it to a previous
 occurance of a DatePattern, on startup only. If the file stat shows
@@ -767,11 +768,11 @@ The name of the object (not the filename!).  Required.
 
 =item -- size ($)
 
-The maxium (or close to) size the log file can grow too.
+The maximum (or close to) size the log file can grow too.
 
 =item -- max ($)
 
-The maxium number of log files to create.
+The maximum number of log files to create.
 
 =item -- TZ ($)
 
